﻿using System;
using IVR.IVR.Menu;
using Ozeki.Media;
using Ozeki.VoIP;

namespace IVR.IVR
{
    class IVRCallHandler
    {
        IPBXCall pbxCall;
        MenuElement rootMenu;

        public IVRCallHandler(IPBXCall pbxCall)
        {
            this.pbxCall = pbxCall;
            
            InitializeIVRMenu();
            pbxCall.CallStateChanged += CallStateChanged;
        }

        private void InitializeIVRMenu()
        {
            rootMenu = new MenuElement("Welcome to OZEKI Interactive Voice Response system. " +
                                       "Please press one to enter a test menu. " +
                                       "Press two to hear some music. " +
                                       "Press three to call someone. " +
                                       "Press four to check your voicemail. ", '0');

            rootMenu.AddSubmenu(new MenuElement("This is a submenu, and you pressed key 1. " +
                                                "You can return to the main menu by pressing 0. ", '0'), '1');
            rootMenu.AddSubmenu(new MenuElement(new WaveStreamPlayback(@"Resources\music.wav"), '0'), '2');
            rootMenu.AddSubmenu(new TransferMenuElement("Please enter the phone number and press the pound key when you are finished. " +
                                                        "We will transfer the call to the phone number you entered. " +
                                                        "You can return to the previous menu with *. ", '*'), '3');
            rootMenu.AddSubmenu(new VoiceMailMenuElement("You will be redirected to check your voice mails. ", '0'), '4');

            rootMenu.Completed += RootMenuCompleted;
        }

        private void RootMenuCompleted(object sender, EventArgs e)
        {
            ((ICall)pbxCall).HangUp();
        }

        private void CallStateChanged(object sender, CallStateChangedArgs e)
        {
            switch (e.State)
            {
                case CallState.Ringing:
                    pbxCall.Answer();
                    break;

                case CallState.InCall:  
                    rootMenu.Execute(pbxCall);
                    break;

                case CallState.Completed:
                    OnCompleted();
                    break;
            }
        }

        public event EventHandler Completed;

        void OnCompleted()
        {
            var handler = Completed;
            if (handler != null)
                handler(this, EventArgs.Empty);
        }
    }
}
